# State Space Generator

## Installation

```console
pip install state_space_generator
```

## How to use

```python
from state_space_generator.state_space_generator import generate_state_space
generate_state_space("domain.pddl", "problem.pddl", max_time=10.0)
```
